# gulp-template-ts

> Render/precompile [Lo-Dash/Underscore templates](http://lodash.com/docs#template)

*Issues with the output should be reported on the Lo-Dash [issue tracker](https://github.com/lodash/lodash/issues).*


## Install

```
$ npm install --save-dev gulp-template-ts
```


## Usage

### `src/greeting.html`

```erb
<h1>Hello <%= name %></h1>
```

### `gulpfile.ts`

```ts
import * as gulp from 'gulp';
import * as template from 'gulp-template-ts';

gulp.task('default', () =>
	gulp.src('src/greeting.html')
		.pipe(template({name: 'Mathias'}))
		.pipe(gulp.dest('dist'))
);
```

You can alternatively use [gulp-data](https://github.com/colynb/gulp-data) to inject the data:

```ts
import * as gulp from 'gulp';
import * as template from 'gulp-template-ts';
import * as data from 'gulp-data';

gulp.task('default', () =>
	gulp.src('src/greeting.html')
		.pipe(data(() => ({name: 'Mathias'})))
		.pipe(template())
		.pipe(gulp.dest('dist'))
);
```

### `dist/greeting.html`

```html
<h1>Hello Mathias</h1>
```


## API

### template(data, [options])

Render a template using the provided `data`.

### template.precompile([options])

Precompile a template for rendering dynamically at a later time.

#### data

Type: `object`

Data object used to populate the text.

#### options

Type: `object`

[Lo-Dash `_.template` options](http://lodash.com/docs#template).


## Related

- [grunt-template](https://github.com/mathiasbynens/grunt-template) - Grunt version


## License

MIT © Mathias Døhl
